@@ -86,6 +86,26 @@ class Review(Base):
         return db.query(Review).filter(Review.is_active == True) \
                                .order_by(Review.completed_date.desc())[:limit]
 
+    @classmethod
+    def get_reviews_count_in_period(cls, db, from_date, to_date=None):
+        if to_date is None:
+            to_date = datetime.utcnow()
+
+        reviews = db \
+            .query(Review.completed_date) \
+            .filter(Review.is_active == True) \
+            .filter(Review.completed_date.between(from_date, to_date)) \
+            .order_by(Review.completed_date.asc()) \
+            .all()
+
+        count = len(reviews)
+
+        first_date = None
+        if count > 0:
+            first_date = reviews[0].completed_date
+
+        return count, first_date
+
     def get_violation_points(self):
         points = 0
         for violation in self.violations:
@@ -197,7 +217,7 @@ class Review(Base):
         return query.order_by(Review.completed_date.desc())[lower_bound:upper_bound]
 
     @classmethod
-    def save_review(cls, page_uuid, review_data, db, fact_definitions, violation_definitions, cache, publish):
+    def save_review(cls, page_uuid, review_data, db, fact_definitions, violation_definitions, cache, publish, config):
         from holmes.models import Page
 
         page = Page.by_uuid(page_uuid, db)
@@ -234,7 +254,6 @@ class Review(Base):
             try:
                 page.expires = review_data['expires']
                 page.last_modified = review_data['lastModified']
-                page.score = 0
                 page.last_review_uuid = review.uuid
                 page.last_review = review
                 page.last_review_date = review.completed_date
@@ -277,6 +296,9 @@ class Review(Base):
                         violation.review_is_active = False
                     last_review.is_active = False
                     db.commit()
+
+                    Review.delete_old_reviews(db, config, page)
+
                     break
                 except Exception:
                     err = sys.exc_info()[1]
@@ -286,9 +308,28 @@ class Review(Base):
                         db.rollback()
                         raise
 
-
-
         publish(dumps({
             'type': 'new-review',
             'reviewId': str(review.uuid)
         }))
+
+    @classmethod
+    def delete_review(cls, db, review):
+        db.begin(subtransactions=True)
+        db.delete(review)
+        db.commit()
+
+    @classmethod
+    def delete_old_reviews(cls, db, config, page):
+        reviews = db \
+            .query(Review) \
+            .filter(Review.is_active == 0) \
+            .filter(Review.page_id == page.id) \
+            .order_by(Review.completed_date.desc()) \
+            .all()
+
+        last_reviews = reviews[config.NUMBER_OF_REVIEWS_TO_KEEP:]
+
+        if len(last_reviews) > 0:
+            for review in last_reviews:
+               cls.delete_review(db, review)
